@@ -43,7 +43,7 @@
 /* TOOLKIT : 2D list                                                 */
 /*********************************************************************/
 
-Set2DList(list)
+void Set2DList(list)
 
 struct TwoDimList *list;
 
@@ -99,7 +99,7 @@ return entry;
 
 /*********************************************************************/
 
-Build2DListFromVarstring(TwoDimlist,varstring,sep)
+void Build2DListFromVarstring(TwoDimlist,varstring,sep)
 
  /* Build a database list with all expansions of a 2D list a */
  /* sep is a separator which is used to split a many-variable */
@@ -110,7 +110,7 @@ char *varstring, sep;
 /* GLOBAL LISTSEPARATOR */
 
 { char format[6], *sp;
-  char node[maxlinksize];
+  char node[bufsize];
   int i;
 
 Debug1("Build2DListFromVarstring(%s,sep=%c)\n",varstring,sep);
@@ -140,8 +140,8 @@ for (sp = varstring; *sp != '\0'; sp++)
    if (strlen(node) == 0)
       {
       continue;
-      } 
-   
+      }
+
    AppendTwoDimItem(TwoDimlist,SplitVarstring(node,LISTSEPARATOR),sep);
 
    if (*sp == '\0')
@@ -153,7 +153,7 @@ for (sp = varstring; *sp != '\0'; sp++)
 
 /*********************************************************************/
 
-IncrementTwoDimList (from,list)
+int IncrementTwoDimList (from,list)
 
 struct TwoDimList *from, *list;
 
@@ -195,7 +195,7 @@ return TD_nowrap; /* Shouldn't get here */
 
 /*********************************************************************/
 
-EndOfTwoDimList(list)       /* bool */
+int EndOfTwoDimList(list)       /* bool */
 
 struct TwoDimList *list;
 
@@ -242,7 +242,7 @@ else
 
 /*********************************************************************/
 
-AppendTwoDimItem(liststart,itemlist,sep)
+void AppendTwoDimItem(liststart,itemlist,sep)
 
 struct TwoDimList **liststart;
 struct Item *itemlist;
@@ -289,7 +289,7 @@ else
 
 /*********************************************************************/
 
-Delete2DList(item)
+void Delete2DList(item)
 
 struct TwoDimList *item;
 
