@@ -256,6 +256,7 @@ extern short D1;
 extern short D2;
 extern short D3;
 
+extern short PARSING;
 extern short ISCFENGINE;
 
 extern short VERBOSE;
@@ -373,7 +374,7 @@ extern int EDITGROUPLEVEL;
 extern int SEARCHREPLACELEVEL;
 extern int FOREACHLEVEL;
 
-extern char *COMMENTSTART, *COMMENTEND;
+extern char COMMENTSTART[], COMMENTEND[];
 
 /* GNU REGEXP */
 
