@@ -312,8 +312,10 @@ if (GetMacroValue("MaxConnections"))
    Debug("$(MaxConnections) Expanded to %s\n",VBUFF);
 
    CFD_MAXPROCESSES = atoi(VBUFF);
-
-   if ((CFD_MAXPROCESSES < 1) || (CFD_MAXPROCESSES > 100))
+   
+   MAXTRIES = CFD_MAXPROCESSES / 3;  /* How many attempted connections over max
+				        before we commit suicide? */
+   if ((CFD_MAXPROCESSES < 1) || (CFD_MAXPROCESSES > 1000))
       {
       FatalError("cfd: MaxConnections with silly value");
       }
@@ -321,6 +323,7 @@ if (GetMacroValue("MaxConnections"))
 else
    {
    CFD_MAXPROCESSES = 10;
+   MAXTRIES = 5;
    }
 
 if (GetMacroValue("AutoExecInterval"))
@@ -851,7 +854,14 @@ if (CFDSTARTTIME < newstat.st_ctime)
    sprintf(OUTPUT,"Rereading config files %s..\n",filename);
    CfLog(cfinform,OUTPUT,"");
 
-   /* Free up memory */
+   /* Free & reload -- lock this to avoid access errors during reload */
+
+#if defined HAVE_PTHREAD_H && defined HAVE_LIBPTHREAD
+   if (pthread_mutex_lock(&MUTEX_COUNT) != 0)
+      {
+      CfLog(cferror,"pthread_mutex_lock failed","lock");
+      }
+#endif
    
    for (i = 0; i < hashtablesize; i++)
       {
@@ -878,6 +888,13 @@ if (CFDSTARTTIME < newstat.st_ctime)
    CheckVariables();
    SummarizeParsing();
    SetAuto(CFD_INTERVAL);
+
+#if defined HAVE_PTHREAD_H && defined HAVE_LIBPTHREAD
+   if (pthread_mutex_unlock(&MUTEX_COUNT) != 0)
+      {
+      CfLog(cferror,"pthread_mutex_unlock failed","unlock");
+      }  
+#endif
    }
 }
 
@@ -932,7 +949,8 @@ if (ACTIVE_THREADS >= CFD_MAXPROCESSES)
    if (pthread_mutex_unlock(&MUTEX_COUNT) != 0)
       {
       CfLog(cferror,"pthread_mutex_unlock failed","unlock");
-      }  
+      }
+   
    CfLog(cfinform,"Too many threads","");
    DeleteConn(conn);
 
@@ -1847,7 +1865,14 @@ CompressPath(realname,filename); /* in links.c */
 #endif
   
 Debug("AccessControl(%s,%s) secure=%d\n",realname,conn->hostname,secure);
-  
+
+#if defined HAVE_PTHREAD_H && defined HAVE_LIBPTHREAD
+   if (pthread_mutex_lock(&MUTEX_COUNT) != 0)
+      {
+      CfLog(cferror,"pthread_mutex_unlock failed","lock");
+      }
+#endif
+ 
 if (VADMIT == NULL)
    {
    Verbose("cfd: access list is empty, no files are visible\n");
@@ -1917,6 +1942,13 @@ else
    CfLog(cfinform,conn->output,"");
    }
 
+#if defined HAVE_PTHREAD_H && defined HAVE_LIBPTHREAD
+if (pthread_mutex_unlock(&MUTEX_COUNT) != 0)
+   {
+   CfLog(cferror,"pthread_mutex_unlock failed","unlock");
+   }  
+#endif
+ 
 return access;
 }
 
@@ -1967,7 +1999,7 @@ if (S_ISLNK(statbuf.st_mode))
    cfst.cf_lmode = statbuf.st_mode & 07777;
    cfst.cf_nlink = statbuf.st_nlink;
        
-   if (readlink(filename,linkbuf,bufsize) == -1)
+   if (readlink(filename,linkbuf,bufsize-1) == -1)
       {
       sprintf(sendbuffer,"BAD: unable to read link\n");
       CfLog(cferror,sendbuffer,"readlink");
