@@ -90,7 +90,7 @@ char *CLASSATTRIBUTES[clssattr][attrdim] =
    "hp-ux","9000*","*",        /* hpux */
    "aix","*","*",              /* aix */
    "linux","*","*",            /* linux */
-   "sunos","sun4?","5*",       /* solaris */
+   "sunos","sun4*","5*",       /* solaris */
    "osf1","alpha","*",         /* osf1 */
    "osf1","alpha","4*",        /* digital */   
    "sunos","sun3","4*",        /* sun3 */
