@@ -1455,7 +1455,9 @@ for (dp = VDISABLELIST; dp != NULL; dp=dp->next)
          continue;
          }
 
-      if (readlink(workname,VBUFF,bufsize) == -1)
+      bzero(VBUFF,bufsize);
+      
+      if (readlink(workname,VBUFF,bufsize-1) == -1)
          {
          sprintf(OUTPUT,"DisableFiles() can't read link %s\n",workname);
 	 CfLog(cferror,OUTPUT,"readlink");
@@ -1875,8 +1877,19 @@ for (ptr=VUNMOUNT; ptr != NULL; ptr=ptr->next)
 	    }
 	 else
 	    {
-	    /* only find fs in proper context ("<host>:<remotepath> <fs> ") */
-	    sprintf(VBUFF,"[^:]+:[^ \t]+[ \t]+%s[ \t]",fs);
+         switch (VSYSTEMHARDCLASS)
+           {
+           case unix_sv:
+           case solarisx86:
+           case solaris:
+             /* find fs in proper context ("<host>:<remotepath> <-> <fs> ") */
+             sprintf(VBUFF,"[^:]+:[^ \t]+[ \t]+[^ \t]+[ \t]+%s[ \t]",fs);
+             break;
+           default:
+             /* find fs in proper context ("<host>:<remotepath> <fs> ") */
+             sprintf(VBUFF,"[^:]+:[^ \t]+[ \t]+%s[ \t]",fs);
+             break;
+           }
 	    item = LocateItemContainingRegExp(filelist,VBUFF);
 	    DeleteItem(&filelist,item);
 	    }
