@@ -254,7 +254,7 @@ if (lstat(filename,&statbuf) != -1)
       bzero(linkname,bufsize);
       bzero(realname,bufsize);
       
-      if (readlink(filename,linkname,bufsize) == -1)
+      if (readlink(filename,linkname,bufsize-1) == -1)
 	 {
 	 sprintf(OUTPUT,"Cannot read link %s\n",filename);
 	 CfLog(cferror,OUTPUT,"readlink");
@@ -392,8 +392,8 @@ NUMBEROFEDITS = 0;
 EDITVERBOSE = VERBOSE;
 CURRENTLINENUMBER = 1;
 CURRENTLINEPTR = filestart;
-COMMENTSTART = "# ";
-COMMENTEND = "";
+strcpy(COMMENTSTART,"# ");
+strcpy(COMMENTEND,"");
 EDITGROUPLEVEL = 0;
 SEARCHREPLACELEVEL = 0;
 FOREACHLEVEL = 0;
@@ -417,6 +417,7 @@ while (ep != NULL)
    switch(ep->code)
       {
       case NoEdit:
+      case EditInform:
       case EditUmask:
       case AutoCreate:
                break;
@@ -568,11 +569,13 @@ while (ep != NULL)
                break;
 
       case SetCommentStart:
-               COMMENTSTART = expdata;
+               strncpy(COMMENTSTART,expdata,maxvarsize);
+               COMMENTSTART[maxvarsize-1] = '\0';
                break;
 
       case SetCommentEnd:
-               COMMENTEND = expdata;
+               strncpy(COMMENTEND,expdata,maxvarsize);
+               COMMENTEND[maxvarsize-1] = '\0';
                break;
 
       case CommentLinesMatching:
@@ -1367,7 +1370,10 @@ for (ep = actions; ep != NULL; ep=ep->next)
    switch(ep->code)
       {
       case AutoCreate: if (!DONTDO)
-	                  {
+	                  { mode_t mask;
+
+			  mask = umask(0);
+			  
 			  if (stat(filename,&statbuf) == -1)
 			     {
 			     if ((fd = creat(filename,0644)) == -1)
@@ -1382,9 +1388,13 @@ for (ep = actions; ep != NULL; ep=ep->next)
 				}
 			     sprintf(OUTPUT,"Creating file %s, mode 644\n",filename);
 			     CfLog(cfinform,OUTPUT,"");
+			     umask(mask);
 			     return;
 			     }
+			  
+			  umask(mask);
 			  }
+                       
                        break;
       
       case EditBackup: if (strcmp("false",ToLowerStr(expdata)) == 0 || strcmp("off",ToLowerStr(expdata)) == 0)
@@ -1634,6 +1644,12 @@ while (ep != NULL)
 	  break;
 
       case EditMode:
+          if (!DONTDO)
+	     {
+	     mode_t plus,minus;
+	     ParseModeString(expdata,&plus,&minus);
+	     chmod(filename,plus);
+	     }
 	  break;
       default:
 	  sprintf(OUTPUT,"Cannot use %s in a binary edit (%s)",VEDITNAMES[ep->code],filename);
