@@ -36,20 +36,21 @@
 #include "../pub/md5.h"
 
 
-#ifdef HAVE_LIBCRYPTO  /* must be des.h from OpenSSL */
-# ifdef HAVE_OPENSSL_DES_H
-#  include <openssl/des.h>
-# endif
+#if defined(HAVE_LIBCRYPTO) || defined(HAVE_OPENSSL_DES_H)
+      /* must be des.h from OpenSSL */
+# include <openssl/des.h>
+# define USE_SSL 1
 #endif
 
 /*********************************************************************/
 
-LoadSecretKeys()
+void LoadSecretKeys()
 
 { char filename[maxvarsize];
   struct stat statbuf;
   char seed[8],digest[16];
   FILE *fp;
+  int sp;
  
 sprintf(filename,"%s/keys",VLOCKDIR);
 
@@ -73,12 +74,32 @@ if ((fp = fopen(filename,"r")) == NULL)
    return;
    }
 
-fscanf(fp,"%8s%8s%8s",CFDES1,CFDES2,CFDES3);
+for (sp = 0; sp < 8; sp++)
+   {
+   CFDES1[sp] = getc(fp);
+   }
+
+ CFDES1[sp] = '\0';
+
+ for (sp = 0; sp < 8; sp++)
+   {
+   CFDES2[sp] = getc(fp);
+   }
+
+ CFDES2[sp] = '\0';
+
+ for (sp = 0; sp < 8; sp++)
+   {
+   CFDES3[sp] = getc(fp);
+   }
+
+ CFDES3[sp] = '\0';
+
 fclose(fp);
 
 Verbose("Loaded DES secret keys from %s\n",filename);
 
-#ifdef HAVE_LIBCRYPTO
+#ifdef USE_SSL
 DESMD5Random(digest);
 bcopy(digest,seed,8);
 des_random_seed((des_cblock *)seed);
@@ -87,7 +108,7 @@ des_random_seed((des_cblock *)seed);
 
 /**************************************************************/
 
-DESMD5Random(digest)
+void DESMD5Random(digest)
 
 char digest[16];
 
@@ -95,14 +116,13 @@ char digest[16];
       MD5. We can use this as a seed for pseudo random generator */
 
 { MD5_CTX context;
-  int len;
   unsigned char buffer[bufsize];
   FILE *pp;
   char pscomm[maxlinksize];
 
 Verbose("Looking for a good random number seed...\n");
 cfMD5Init (&context);
-sprintf(buffer,"%d%d",CFSTARTTIME,digest);
+sprintf(buffer,"%d%d",(int)CFSTARTTIME,(int)digest);
 cfMD5Update (&context, buffer,bufsize);
 
 sprintf(pscomm,"%s %s",VPSCOMM[VSYSTEMHARDCLASS],VPSOPTS[VSYSTEMHARDCLASS]);
@@ -126,12 +146,12 @@ cfMD5Final (digest, &context);
 
 /*********************************************************************/
 
-#ifdef HAVE_LIBCRYPTO
+#ifdef USE_SSL
 
-cfencrypt(in,out,key1,key2,key3,len)
+void cfencrypt(in,out,key1,key2,key3,len)
 
 char *in,*out;
-char key1[8],key2[8];
+char key1[8],key2[8],key3[8];
 int len;
 
 { char workvec[bufsize];
@@ -148,7 +168,7 @@ des_ede3_cbc_encrypt(in,out,(long)len,ks1,ks2,ks3,(C_Block *)workvec,DES_ENCRYPT
 
 /*********************************************************************/
 
-cfdecrypt(in,out,key1,key2,key3,len)
+void cfdecrypt(in,out,key1,key2,key3,len)
 
 char *in,*out;
 char key1[8],key2[8],key3[8];
@@ -171,12 +191,26 @@ Debug("Decrypted %d to [%d]\n",len,strlen(out));
 
 #else
 
-cfencrypt()
+void cfencrypt(in,out,key1,key2,key3,len)
+
+char *in,*out;
+char key1[8],key2[8],key3[8];
+int len;
+
 {
+Debug("No encryption available...\n");
 }
 
-cfdecrypt()
+/*********************************************************************/
+
+void cfdecrypt(in,out,key1,key2,key3,len)
+
+char *in,*out;
+char key1[8],key2[8],key3[8];
+int len;
+
 {
+Debug("No decryption available...\n");
 }
 
 #endif
