@@ -167,8 +167,8 @@ strncpy(VHR,buf,2);
 sscanf(buf4,"%*[^:]:%[^:]",buf);
 sprintf(out,"Min%s",buf);
 AddClassToHeap(out);
-bzero(VMIN,3);
-strncpy(VMIN,buf,2); 
+bzero(VMINUTE,3);
+strncpy(VMINUTE,buf,2); 
  
 sscanf(buf,"%d",&i);
 
