@@ -101,7 +101,7 @@ char *alias,*type,*data;
 
 { int crit = (int) FilterActionsToCode(type), i = -1;
   struct Filter *fp;
-  char buffer[bufsize],units='x';
+  char buffer[bufsize],units='x',*sp;
   time_t now;
   
 Debug("InstallFilterTest(%s,%s,%s)\n",alias,type,data);
@@ -176,6 +176,17 @@ else
 		sprintf(buffer,"%d",i);
 		break;
 	    case filterexecregex:
+		for (sp = buffer+strlen(buffer)-1; (*sp != '(') && (sp > buffer); sp--)
+		   {
+		   }
+		
+		sscanf(sp+1,"%.256[^)]",VBUFF);
+		if (!RegexOK(VBUFF))
+		   {
+		   yyerror("Regular expression error");
+		   }
+		break;
+		
 	    case filternameregex:
 		if (!RegexOK(buffer))
 		   {
@@ -1232,26 +1243,32 @@ int FilterExecRegexMatch(filename,crit)
 
 char *filename,*crit;
 
-  /* Check checksum if use file program... */
-
 { regex_t rx;
   regmatch_t pmatch;
-  char buffer[bufsize],expr[bufsize],line[bufsize];
+  char buffer[bufsize],expr[bufsize],line[bufsize],*sp;
   FILE *pp;
 
+AddMacroValue("this",filename);
+VBUFF[0] = '\0'; 
+ExpandVarstring(crit,VBUFF,NULL);
+DeleteMacro("this");
+  
 bzero(buffer,bufsize);
 bzero(line,bufsize); 
 bzero(expr,bufsize);
+
+for (sp = VBUFF+strlen(VBUFF)-1; (*sp != '(') && (sp > VBUFF); sp--)
+   {
+   }
+ 
+sscanf(sp+1,"%.256[^)]",expr);
+strncpy(buffer,VBUFF,(int)(sp-VBUFF));
  
-sscanf(crit,"%[^(](%[^\n])",buffer,expr);
-  
 if (CfRegcomp(&rx,expr,REG_EXTENDED) != 0)
    {
    return false;
    }            
 
-sprintf(buffer,"Not yet implemented");
-
 if ((pp = cfpopen(buffer,"r")) == NULL)
    {
    sprintf(OUTPUT,"Couldn't open pipe to command %s\n",buffer);
@@ -1290,8 +1307,10 @@ if (CfRegcomp(&rx,crit,REG_EXTENDED) != 0)
    {
    return false;
    }
+
+bzero(buffer,bufsize);
  
-if (readlink(filename,buffer,bufsize) == -1)
+if (readlink(filename,buffer,bufsize-1) == -1)
    {
    sprintf(OUTPUT,"Unable to read link %s in filter",filename);
    CfLog(cferror,OUTPUT,"readlink");
