@@ -450,6 +450,7 @@ char PADCHAR = ' ';
 
   PUBLIC short ISCFENGINE;  /* for re-using parser code in cfd */
 
+  PUBLIC  short PARSING = false;
   PRIVATE short TIDYDIRS = false;
   PRIVATE short TRAVLINKS = false;
   PRIVATE short PTRAVLINKS = false;
@@ -695,8 +696,8 @@ char PADCHAR = ' ';
 
   PRIVATE int AUTOCREATED = 0;
 
-  PRIVATE char *COMMENTSTART;
-  PRIVATE char *COMMENTEND;
+  PRIVATE char COMMENTSTART[maxvarsize];
+  PRIVATE char COMMENTEND[maxvarsize];
 
   PUBLIC char *VEDITNAMES[] =
      {
