@@ -264,9 +264,13 @@ char *vifdev,*vnetmask, *vbroadcast;
 /* set netmask */
 
 Verbose("Resetting interface...\n");
-strcpy(IFR.ifr_name,vifdev);
+
+memset(&IFR, 0, sizeof(IFR));
+strncpy(IFR.ifr_name,vifdev,sizeof(IFR.ifr_name)); 
 netmask.sin_addr.s_addr = inet_network(vnetmask);
+netmask.sin_family = AF_INET;
 IFR.ifr_addr = *((struct sockaddr *) &netmask);
+
 sin = (struct sockaddr_in *) &IFR.ifr_addr;
 
 if (ioctl(sk,SIOCSIFNETMASK, (caddr_t) &IFR) < 0) 
