@@ -355,7 +355,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
 	 CfLog(cfverbose,OUTPUT,"");
 	 
 	 bzero(VBUFF,bufsize);
-         if (readlink(newto,VBUFF,bufsize) != -1)
+         if (readlink(newto,VBUFF,bufsize-1) != -1)
             {
             Verbose("File is link to -> %s\n",VBUFF);
             }
@@ -565,7 +565,7 @@ if (lstat(from,&buf) == 0)
 
 bzero(linkbuf,bufsize);
 
-if (readlink(from,linkbuf,bufsize) == -1)
+if (readlink(from,linkbuf,bufsize-1) == -1)
    {
    if (! MakeDirectoriesFor(from))                  /* link doesn't exist */
       {
@@ -821,7 +821,7 @@ Debug("KillOldLink(%s)\n",name);
 bzero(linkbuf,bufsize);
 bzero(linkpath,bufsize); 
 
-if (readlink(name,linkbuf,bufsize) == -1)
+if (readlink(name,linkbuf,bufsize-1) == -1)
    {
    sprintf(OUTPUT,"(Can't read link %s while checking for deadlinks)\n",name);
    CfLog(cfverbose,OUTPUT,"");
@@ -1089,7 +1089,7 @@ for (sp = from; *sp != '\0'; sp++)
       {
       bzero(buff,bufsize);
       
-      if (readlink(dest,buff,bufsize) == -1)
+      if (readlink(dest,buff,bufsize-1) == -1)
 	 {
 	 sprintf(OUTPUT,"Expand links can't stat %s\n",dest);
 	 CfLog(cferror,OUTPUT,"readlink");
