@@ -71,9 +71,6 @@ char CFLOCK[bufsize];
 char CFLOG[bufsize];
 char CFLAST[bufsize];
 
-time_t GetLastLock();
-time_t CheckOldLock();
-
 /********************************************************************/
  
 void HandleSignal(signum)
@@ -93,8 +90,8 @@ if (signum == SIGTERM || signum == SIGINT || signum == SIGHUP)
 }
 
 /************************************************************************/
- 
-GetLock(operator,operand,ifelapsed,expireafter,host,now)
+
+int GetLock(operator,operand,ifelapsed,expireafter,host,now)
 
 char *operator, *operand, *host;
 int ifelapsed, expireafter;
@@ -124,14 +121,14 @@ sprintf(CFLOG,"%s/cfengine.%s.runlog",VLOGDIR,host);
 sprintf(CFLOCK,"%s/lock.%s.%s.%s.%s",VLOCKDIR,VCANONICALFILE,host,operator,operand);
 sprintf(CFLAST,"%s/last.%s.%s.%s.%s",VLOCKDIR,VCANONICALFILE,host,operator,operand);
 
-if (strlen(CFLOCK) > 254)
+if (strlen(CFLOCK) > MAX_FILENAME)
    {
-   CFLOCK[253] = '\0';  /* most nodenames are 255 chars or less */
+   CFLOCK[MAX_FILENAME] = '\0';  /* most nodenames are 255 chars or less */
    }
 
-if (strlen(CFLAST) > 254)
+if (strlen(CFLAST) > MAX_FILENAME)
    {
-   CFLAST[253] = '\0';  /* most nodenames are 255 chars or less */
+   CFLAST[MAX_FILENAME] = '\0';  /* most nodenames are 255 chars or less */
    }
 
 /* Look for non-existent (old) processes */
@@ -209,7 +206,7 @@ return true;
  
 /************************************************************************/
 
-ReleaseCurrentLock()
+void ReleaseCurrentLock()
 
 { int fd;
 
@@ -244,12 +241,10 @@ LockLog(getpid(),"Lock removed normally",CFLOCK,"");
 
 /************************************************************************/
 
-CountActiveLocks(now)
+int CountActiveLocks()
 
  /* Count the number of active locks == number of cfengines running */
 
-time_t now;
-
 { DIR *dirh;
   struct dirent *dirp;
   int count = 0;
@@ -332,7 +327,7 @@ else
 
 /************************************************************************/
 
-GetLockPid()
+int GetLockPid()
 
 { FILE *fp;
   int pid = -1;
@@ -352,7 +347,7 @@ return pid;
 
 /************************************************************************/
 
-SetLock()
+void SetLock()
 
 { FILE *fp;
 
@@ -373,7 +368,7 @@ chmod(CFLOCK,0644);
 
 /************************************************************************/
 
-LockLog(pid,str,operator,operand)
+void LockLog(pid,str,operator,operand)
 
 int pid;
 char *str, *operator, *operand;
