@@ -37,20 +37,11 @@
 #include "../pub/global.h"
 #include "../pub/md5.h"
 
-#ifdef HAVE_DB_2_H
-# include <db_2.h>
-#else
-# if defined HAVE_DB_H && defined HAVE_DB_185_H
-#  include <db.h>
-# endif
+
+#ifdef HAVE_DB_H
+# include <db.h>
 #endif
 
-#if HAVE_DB_DB_H
-# include <db/db.h>
-#endif
-
-
-
 /*******************************************************************/
 
 void GetNameInfo()
@@ -457,15 +448,16 @@ int warnlevel,refresh;
   int i, matched, needupdate = false;
   char dbvalue[17],dbdigest[17];
   time_t tloc;
-#if defined HAVE_LIBDB && (defined HAVE_DB_H || defined HAVE_DB_DB_H) && defined HAVE_DB_185_H
+#if defined HAVE_LIBDB
   DBT key,value;
   DB *dbp;
+  DB_ENV *dbenv = NULL;
   DBC *dbcp;
   db_recno_t recno;
   
 Debug("ChecksumChanged: key %s in %s with data %s\n",filename,CHECKSUMDB,cfMDPrint(digest));
 
- if (CHECKSUMDB[0] == '\0')
+ if (CHECKSUMDB == NULL)
    {
    if (ISCFENGINE)
       {
@@ -516,15 +508,24 @@ if (refresh)
       }      
    }
  
- /* Open the database. */
-
-if ((errno = db_open(CHECKSUMDB,DB_BTREE, DB_CREATE, 0664, NULL, NULL, &dbp)) != 0)
+ /* Open the database. -- do we need an environment now? */
+ 
+if ((errno = db_create(&dbp,dbenv,0)) != 0)
    {
    sprintf(OUTPUT,"cfd: couldn't open checksum database %s\n",CHECKSUMDB);
    CfLog(cferror,OUTPUT,"db_open");
    Debug("Ended 2\n");
    return false;
    }
+ 
+if ((errno = dbp->open(dbp,CHECKSUMDB,NULL,DB_BTREE,DB_CREATE,0664)) != 0)
+   {
+   sprintf(OUTPUT,"cfd: couldn't open checksum database %s\n",CHECKSUMDB);
+   CfLog(cferror,OUTPUT,"db_open");
+   Debug("Ended 2.1\n");
+   dbp->close(dbp,0);
+   return false;
+   }
 
 Debug("Opening database file %s\n",CHECKSUMDB); 
 bzero(&value,sizeof(value)); 
@@ -651,7 +652,7 @@ else
    }
 
 #else
-Verbose("cfd: No Berkeley DB2 database support available.\n");
+Verbose("cfd: No Berkeley DB3 database support available.\n");
 
 if (!ISCFENGINE)
    {
