@@ -62,6 +62,8 @@ void ParseInputFiles()
   char filename[bufsize], *sp;
   void TimeOut();
 
+PARSING = true;
+  
 if ((strcmp(VINPUTFILE,".") == 0)||(strcmp(VINPUTFILE,"-") == 0)) /* read from standard input */
    {
    yyin = stdin;
@@ -209,6 +211,8 @@ for (ptr = VIMPORT; ptr != NULL; ptr=ptr->next)
 
 VCURRENTFILE[0]='\0';       /* Zero filename for subsequent errors */
 
+PARSING = false;
+ 
 Debug("(END OF PARSING)\n");
 }
 
