@@ -138,6 +138,7 @@ int CopyRegNet ARGLIST((char *source, char *new, struct Image *ip, off_t size));
 int GetCachedStatData ARGLIST((char *file, struct stat *statbuf, struct Image *ip, char *stattype));
 void CacheData ARGLIST((struct cfstat *data, struct Image *ip));
 void FlushToEnd ARGLIST((int sd, int toget));
+int cfprintf(char *out, int len2, char *in1, char *in2, char *in3);
 
 /* comparray.c */
 
@@ -557,6 +558,8 @@ int ChecksumChanged ARGLIST((char *filename, char *digest, int warnlevel, int re
 int IgnoredOrExcluded ARGLIST((enum actions action, char *file, struct Item *inclusions, struct Item *exclusions));
 void Banner ARGLIST((char *string));
 void SetDomainName ARGLIST((char *sp));
+void GetInterfaceInfo ARGLIST((void));
+
 
 /* modes.c */
 
