@@ -37,17 +37,33 @@
 
 /*********************************************************************/
 
-Repository(file)
+int Repository(file,repository)
 
-char *file;
+char *file, *repository;
+
+ /* Returns true if the file was backup up and false if not */
 
 { char buffer[bufsize];
+  char localrepository[bufsize]; 
   char node[maxlinksize];
   struct stat sstat, dstat;
   char *sp;
   struct Image dummy;
   short imagecopy;
 
+if (repository == NULL)
+   {
+   strcpy(localrepository,VREPOSITORY);
+   }
+else
+   {
+   if (strcmp(repository,"none") == 0 || strcmp(repository,"off") == 0)
+      {
+      return false;
+      }
+   strcpy(localrepository,repository);
+   }
+
 if (!IMAGEBACKUP)
    {
    return true;
@@ -55,12 +71,16 @@ if (!IMAGEBACKUP)
 
 if (IsItemIn(VREPOSLIST,file))
    {
+   sprintf(OUTPUT,"The file %s has already been moved to the repository once.",file);
+   CfLog(cfinform,OUTPUT,"");
+   sprintf(OUTPUT,"Multiple update will cause loss of backup. Use backup=false in copy to override.");
+   CfLog(cfinform,OUTPUT,"");
    return true;
    }
 
 PrependItem(&VREPOSLIST,file,NULL);
 
-if (VREPOSITORY[0] == '\0' || HOMECOPY)
+if ((strlen(localrepository) == 0) || HOMECOPY)
    {
    return false;
    }
@@ -79,7 +99,7 @@ for (sp = node; *sp != '\0'; sp++)
       }
    }
 
-strcpy(buffer,VREPOSITORY);
+strcpy(buffer,localrepository);
 AddSlash(buffer);
 
 if (BufferOverflow(buffer,node))
