@@ -46,7 +46,7 @@ char *VSKIPFILES[] =
 
 /*********************************************************************/
 
-SensibleFile(nodename,path,ip)
+int SensibleFile(nodename,path,ip)
 
 char *nodename, *path;
 struct Image *ip;
@@ -158,7 +158,7 @@ if (strstr(nodename,".") && (EXTENSIONLIST != NULL))
 	 {
 	 sp++; /* Find file extension, look for known plain files  */
 
-	 if (IsItemIn(EXTENSIONLIST,sp))
+	 if ((strlen(sp) > 0) && IsItemIn(EXTENSIONLIST,sp))
 	    {
 	    sprintf(OUTPUT,"Suspicious directory %s in %s looks like plain file with extension .%s",nodename,path,sp);
 	    CfLog(cfsilent,OUTPUT,"");
